Thread (32 messages) 32 messages, 5 authors, 2005-04-25

Re: Re: 2.6.12-rc1-mm2 -- nvidiafb driver gives black screen

From: Antonino A. Daplas <hidden>
Date: 2005-04-25 03:24:33

On Monday 25 April 2005 01:09, Miles Lane wrote:
On 4/22/05, Miles Lane [off-list ref] wrote:
quoted
Okay, it also fails with Antonio's patches applied in addition to yours.
I know I implied this in my previous message, but I want to make it
explicit. This combination of patches also fails to give a working
framebuffer console when I specify vmalloc=128M.  I only get a working
framebuffer console by specifying vmalloc=256M.

           Miles
Can you try this patch?  This limits the amount of RAM that nvidiafb
will remap to 64 MiB.  This is on top of another patch I sent to Andrew:
"[Linux-fbdev-devel] [PATCH 1/6] nvidiafb: ioremap and i2c fixes"

Tony

diff -Nru a/drivers/video/nvidia/nvidia.c b/drivers/video/nvidia/nvidia.c
--- a/drivers/video/nvidia/nvidia.c	2005-04-16 11:54:44 +08:00
+++ b/drivers/video/nvidia/nvidia.c	2005-04-25 10:39:45 +08:00
@@ -1511,9 +1511,9 @@
 	if (vram && vram * 1024 * 1024 < par->FbMapSize)
 		par->FbMapSize = vram * 1024 * 1024;
 
-	/* Limit amount of vram to 128 MB */
-	if (par->FbMapSize > 128 * 1024 * 1024)
-		par->FbMapSize = 128 * 1024 * 1024;
+	/* Limit amount of vram to 64 MB */
+	if (par->FbMapSize > 64 * 1024 * 1024)
+		par->FbMapSize = 64 * 1024 * 1024;
 
 	par->FbUsableSize = par->FbMapSize - (128 * 1024);
 	par->ScratchBufferSize = (par->Architecture < NV_ARCH_10) ? 8 * 1024 :




-------------------------------------------------------
SF email is sponsored by - The IT Product Guide
Read honest & candid reviews on hundreds of IT Products from real users.
Discover which products truly live up to the hype. Start reading now.
http://ads.osdn.com/?ad_id=6595&alloc_id=14396&op=click
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help